@@ -49,16 +49,11 @@ import tim.prune.function.compress.MarkPointsInRectangleFunction;
 import tim.prune.function.deletebydate.DeleteByDateFunction;
 import tim.prune.function.distance.DistanceFunction;
 import tim.prune.function.edit.PointNameEditor;
+import tim.prune.function.edit.ToggleSegmentFlag;
 import tim.prune.function.edit.TruncatePointCoords;
 import tim.prune.function.estimate.EstimateTime;
 import tim.prune.function.estimate.LearnParameters;
-import tim.prune.function.settings.SaveConfig;
-import tim.prune.function.settings.SetAltitudeTolerance;
-import tim.prune.function.settings.SetColours;
-import tim.prune.function.settings.SetDisplaySettings;
-import tim.prune.function.settings.SetLanguage;
-import tim.prune.function.settings.SetMapBgFunction;
-import tim.prune.function.settings.SetPathsFunction;
+import tim.prune.function.settings.*;
 import tim.prune.function.sew.SewTrackSegmentsFunction;
 import tim.prune.function.sew.SplitSegmentsFunction;
 import tim.prune.function.srtm.LookupSrtmFunction;
@@ -87,6 +82,7 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_IMPORTBABEL = null;
 	public static GenericFunction FUNCTION_SAVECONFIG  = null;
 	public static GenericFunction FUNCTION_EDIT_WAYPOINT_NAME = null;
+	public static GenericFunction FUNCTION_TOGGLE_POINT_SEGMENT = null;
 	public static GenericFunction FUNCTION_PROJECT_POINT = null;
 	public static GenericFunction FUNCTION_PROJECT_CIRCLE = null;
 	public static GenericFunction FUNCTION_REARRANGE_WAYPOINTS = null;
@@ -138,6 +134,7 @@ public abstract class FunctionLibrary
 	public static GenericFunction FUNCTION_PLAY_AUDIO = null;
 	public static GenericFunction FUNCTION_STOP_AUDIO = null;
 	public static GenericFunction FUNCTION_SET_DISPLAY_SETTINGS = null;
+	public static GenericFunction FUNCTION_SET_WAYPOINT_DISPLAY = null;
 	public static GenericFunction FUNCTION_SET_MAP_BG = null;
 	public static GenericFunction FUNCTION_SET_DISK_CACHE = null;
 	public static GenericFunction FUNCTION_SET_PATHS  = null;
@@ -166,6 +163,7 @@ public abstract class FunctionLibrary
 		FUNCTION_IMPORTBABEL = new BabelLoadFromFile(inApp);
 		FUNCTION_SAVECONFIG = new SaveConfig(inApp);
 		FUNCTION_EDIT_WAYPOINT_NAME = new PointNameEditor(inApp);
+		FUNCTION_TOGGLE_POINT_SEGMENT = new ToggleSegmentFlag(inApp);
 		FUNCTION_PROJECT_POINT = new ProjectPoint(inApp);
 		FUNCTION_PROJECT_CIRCLE = new ProjectCircle(inApp);
 		FUNCTION_REARRANGE_WAYPOINTS = new RearrangeWaypointsFunction(inApp);
@@ -217,6 +215,7 @@ public abstract class FunctionLibrary
 		FUNCTION_STOP_AUDIO = new StopAudioFunction(inApp);
 		FUNCTION_DISCONNECT_AUDIO = new DisconnectAudioFunction(inApp);
 		FUNCTION_SET_DISPLAY_SETTINGS = new SetDisplaySettings(inApp);
+		FUNCTION_SET_WAYPOINT_DISPLAY = new SetWaypointSettings(inApp);
 		FUNCTION_SET_MAP_BG = new SetMapBgFunction(inApp);
 		FUNCTION_SET_DISK_CACHE = new DiskCacheConfig(inApp);
 		FUNCTION_SET_PATHS = new SetPathsFunction(inApp);
