@@ -451,8 +451,7 @@ public abstract class Coordinate
 		double startValue = inStart.getDouble();
 		double endValue = inEnd.getDouble();
 		double newValue = startValue + (endValue - startValue) * inFraction;
-		Coordinate answer = inStart.makeNew(newValue, Coordinate.FORMAT_DECIMAL_FORCE_POINT);
-		return answer;
+		return inStart.makeNew(newValue, Coordinate.FORMAT_DECIMAL_FORCE_POINT);
 	}
 
 
