@@ -11,13 +11,6 @@ public abstract class MediaList
 	protected ArrayList<MediaObject> _media = null;
 
 
-	/**
-	 * Empty constructor
-	 */
-	public MediaList() {
-		this(null);
-	}
-
 	/**
 	 * Constructor
 	 * @param inList ArrayList containing media objects
@@ -139,20 +132,6 @@ public abstract class MediaList
 	}
 
 
-	/**
-	 * @return array of file names
-	 */
-	public String[] getNameList()
-	{
-		final int num = getNumMedia();
-		String[] names = new String[num];
-		for (int i=0; i<num; i++) {
-			names[i] = getMedia(i).getName();
-		}
-		return names;
-	}
-
-
 	/**
 	 * @return true if list contains correlated media
 	 */
