@@ -91,16 +91,7 @@ public class AboutScreen extends GenericFunction
 		buildLabel.setAlignmentX(JLabel.CENTER_ALIGNMENT);
 		aboutPanel.add(buildLabel);
 		aboutPanel.add(new JLabel(" "));
-		StringBuffer descBuffer = new StringBuffer();
-		descBuffer.append("<p>").append(I18nManager.getText("dialog.about.summarytext1")).append("</p>");
-		descBuffer.append("<p>").append(I18nManager.getText("dialog.about.summarytext2")).append("</p>");
-		descBuffer.append("<p>").append(I18nManager.getText("dialog.about.summarytext3")).append("</p>");
-		descBuffer.append("<p>").append(I18nManager.getText("dialog.about.languages")).append(" : ")
-			.append("afrikaans, \u010de\u0161tina, deutsch, english, espa\u00F1ol, fran\u00E7ais, italiano,<br>" +
-				" magyar, nederlands, polski, portugu\u00EAs, rom\u00E2n\u0103, suomi, svenska, \u0440\u0443\u0441\u0441\u043a\u0438\u0439 (russian),<br>" +
-				" \u4e2d\u6587 (chinese), \u65E5\u672C\u8A9E (japanese), \uD55C\uAD6D\uC5B4/\uC870\uC120\uB9D0 (korean), schwiizerd\u00FC\u00FCtsch</p>");
-		descBuffer.append("<p>").append(I18nManager.getText("dialog.about.translatedby")).append("</p>");
-		JEditorPane descPane = new JEditorPane("text/html", descBuffer.toString());
+		JEditorPane descPane = new JEditorPane("text/html", getDescHtml());
 		descPane.setBorder(BorderFactory.createEmptyBorder(3, 3, 3, 3));
 		descPane.setEditable(false);
 		descPane.setOpaque(false);
@@ -196,7 +187,7 @@ public class AboutScreen extends GenericFunction
 			new JLabel(" Gy\u00F6rgy, HooAU, Sergey, P\u00E9ter, serhijdubyk, Peter, Cristian,"),
 			1, 6);
 		addToGridBagPanel(creditsPanel, gridBag, constraints,
-			new JLabel(" Roman, Erkki, Carlos, Tche333"),
+			new JLabel(" Roman, Erkki, Carlos, Tche333, J.M."),
 			1, 7);
 		addToGridBagPanel(creditsPanel, gridBag, constraints,
 			new JLabel(I18nManager.getText("dialog.about.credits.translations") + " : "),
@@ -266,6 +257,22 @@ public class AboutScreen extends GenericFunction
 		return mainPanel;
 	}
 
+	/**
+	 * @return contents of the description pane as html
+	 */
+	private String getDescHtml()
+	{
+		return "<p>" + I18nManager.getText("dialog.about.summarytext1") + "</p>"
+			+ "<p>" + I18nManager.getText("dialog.about.summarytext2") + "</p>"
+			+ "<p>" + I18nManager.getText("dialog.about.summarytext3") + "</p>"
+			+ "<p>" + I18nManager.getText("dialog.about.languages") + " : "
+				+ "afrikaans, catal\u00e0, \u010de\u0161tina, deutsch, english, espa\u00F1ol, fran\u00E7ais,<br>" +
+				" italiano, magyar, nederlands, polski, portugu\u00EAs, rom\u00E2n\u0103, suomi, svenska,<br>" +
+				" \u0440\u0443\u0441\u0441\u043a\u0438\u0439 (russian), \u4e2d\u6587 (chinese), \u65E5\u672C\u8A9E (japanese), \uD55C\uAD6D\uC5B4/\uC870\uC120\uB9D0 (korean),<br>" +
+				" schwiizerd\u00FC\u00FCtsch</p>"
+			+ "<p>" + I18nManager.getText("dialog.about.translatedby") + "</p>";
+	}
+
 	/**
 	 * Helper function to reduce complexity of gui-making code
 	 * when adding labels to a GridBagLayout
